@@ -597,6 +597,36 @@ finalize_layout (tree t) {
         continue;
       }
 
+      if (is_func (v, BEGIN) && v[0] == "tmcompact") {
+        r << tree (BEGIN, "compact");
+        continue;
+      }
+
+      if (is_func (v, END) && v[0] == "tmcompact") {
+        r << tree (END, "compact");
+        continue;
+      }
+
+      if (is_func (v, BEGIN) && v[0] == "tmcompressed") {
+        r << tree (BEGIN, "compressed");
+        continue;
+      }
+
+      if (is_func (v, END) && v[0] == "tmcompressed") {
+        r << tree (END, "compressed");
+        continue;
+      }
+
+      if (is_func (v, BEGIN) && v[0] == "tmamplified") {
+        r << tree (BEGIN, "amplified");
+        continue;
+      }
+
+      if (is_func (v, END) && v[0] == "tmamplified") {
+        r << tree (END, "amplified");
+        continue;
+      }
+
       if (is_func (v, BEGIN) && v[0] == "tmindent") {
         r << tree (BEGIN, "indent");
         continue;
@@ -607,6 +637,16 @@ finalize_layout (tree t) {
         continue;
       }
 
+      if (is_func (v, BEGIN) && v[0] == "tmjumpin") {
+        r << tree (BEGIN, "jump-in");
+        continue;
+      }
+
+      if (is_func (v, END) && v[0] == "tmjumpin") {
+        r << tree (END, "jump-in");
+        continue;
+      }
+
       if (is_func (v, BEGIN) && v[0] == "tmlisting") {
         r << tree (BEGIN, "listing");
         continue;
